@@ -1,8 +1,9 @@
 # This file is part of Tryton.  The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
 
+from trytond.model import fields, tree
+from trytond.modules.product_price_list.price_list import Null
 from trytond.pool import PoolMeta
-from trytond.model import tree, fields
 
 
 class PriceList(tree(), metaclass=PoolMeta):
@@ -10,13 +11,14 @@ class PriceList(tree(), metaclass=PoolMeta):
 
     parent = fields.Many2One('product.price_list', "Parent")
 
-    def get_context_formula(self, party, product, unit_price, quantity, uom,
-            pattern=None):
-        context = super(PriceList, self).get_context_formula(
-            party, product, unit_price, quantity, uom, pattern=pattern)
+    def get_context_formula(self, product, quantity, uom, pattern=None):
+        context = super().get_context_formula(
+            product, quantity, uom, pattern=pattern)
         if self.parent:
             parent_unit_price = self.parent.compute(
-                party, product, unit_price, quantity, uom, pattern=pattern)
+                product, quantity, uom, pattern=pattern)
+            if parent_unit_price is None:
+                parent_unit_price = Null()
             context['names']['parent_unit_price'] = parent_unit_price
         return context
 
